<?php 

$lang['Page data'] = 'Page data';
$lang['Page name in admin panel'] = 'Page name in admin panel';
$lang['Page alias'] = 'Page alias';
$lang['Active'] = 'Active?';
$lang['SEO'] = 'SEO';
$lang['Title'] = 'Title';
$lang['Keywords'] = 'Keywords';
$lang['Description'] = 'Description';
$lang['This field specifies the URL to the page. <br />For example, if you write `my_page` then page will be available at `http://mydomain.com/my_page`'] = 'This field specifies the URL to the page. <br />For example, if you write `my_page` then page will be available at `http://mydomain.com/my_page`';
