<ul id="resmng_contextmenu_tree" style="display:none">
    <li><a href="#" onclick="treeMenuRefresh()">{item_refresh}</a></li>

    <?php if ($this->rt_user->isAllowed('resmng', 'rename_element')) { ?>
        <li><a href="#" onclick="treeMenuItemRename()">{item_rename}</a></li>
    <?php } ?>

    <?php if ($this->rt_user->isAllowed('resmng', 'clone_element')) { ?>
        <li><a href="#" onclick="treeMenuItemClone('{item_clone}')">{item_clone}</a></li>
    <?php } ?>

    <?php if ($this->rt_user->isAllowed('resmng', 'create_element')) { ?>
        <li><a href="#">{item_create}</a>
            <ul>
                {create_list}
                <li><a href="#" onclick="treeMenuItemCreate('{id_resource_type}', '{alias}')"><i class="{icon}"></i> {alias}</a></li>
                {/create_list}
            </ul>
        </li>
    <?php } ?>

    <?php if ($this->rt_user->isAllowed('resmng', 'delete_element')) { ?>
        <li><a href="#" onclick="treeMenuTrashAction(0, '{item_delete}')">{item_delete}</a></li>
    <?php } ?>
</ul>