<?php 

$lang['ln_page_template'] = 'Page template';
$lang['ln_alias'] = 'Alias';
$lang['ln_route'] = 'Routing';
$lang['ln_cache'] = 'Cache this page';
$lang['ln_active'] = 'Active';
$lang['ln_seo_title'] = 'SEO title';
$lang['ln_seo_keywords'] = 'SEO keywords';
$lang['ln_seo_description'] = 'SEO description';
