<?php 

$lang['ln_resource'] = 'Ресурси';
$lang['ln_deleted'] = 'Кошик';

$lang['item_refresh'] = 'Обновити';
$lang['item_rename'] = 'Перейменувати';
$lang['item_create'] = 'Створити';
$lang['item_delete'] = 'Видалити';
$lang['item_clone'] = 'Клонувати';

$lang['item_recovery'] = 'Відновити';
$lang['item_clear'] = 'Очистити';