#item_rename{
    border: 1px solid #ccc;
    width: 100px;
}
.resmng_tree_menu i.icon-eye-close, .resmng_tree_menu i.icon-eye-open{
	position: absolute;
	top: 9px;
	right: 3px;
}
#resmng_contextmenu_tree .ui-menu {
    width: 200px; 
}
.resmng_tree_menu .empty-level{
    position: relative
}
.resmng_tree_menu .empty-level ul{
    height: 20px;
    position: absolute;
    top: 5px;
    left: 0;
    z-index: -2;
    width: 100%
}
.resmng_tree_menu  li.convolute ul{
    display: none;
}
.resmng_tree_menu{
    float: left;
    width: 100%;
    color: #363636;
}
.sub-menu li{
    background-color: #f9f9f9;
    margin-bottom: 1px;
    line-height: 34px;
    font-size: 13px;
}
.sub-menu li a{
    display: block;
    padding-left: 40px;
    position: relative;
}
.sub-menu li a span{
	position: relative;
}
.sub-menu li a:hover{
    text-decoration: none;
}
.sub-menu .active{
    color: white;
    background-color: #363636;
}
.sub-menu .active a:hover{
    color: inherit;
    background-color: inherit;
}
.sub-menu ul li{
    background-color: #f9f9f9;
    margin-bottom: 1px;
    background-color: white;
}
.sub-menu a:hover{
    cursor: pointer;
}
.sub-menu a:hover, .inAction {
    background-color: #ebebeb;
}
.sub-menu li li a{
    padding-left: 60px;
}
.sub-menu li li li a{
	padding-left: 80px;
}
.sub-menu li li li li a{
	padding-left: 100px;
}
.sub-menu .sub-level:not(.empty-level) > a span:before{
    content: "";
    display: block;
    position: absolute;
    top: 4px;
    border-style: solid;
    border-width: 8px 5px 0 5px;
    border-color: #363636 transparent transparent transparent;
    left: -38px;
}
.sub-menu .sub-level.convolute > a span:before{
	border-width: 5px 0 5px 8px;
	border-color: transparent transparent transparent #363636;
}
div:not(.resmng_tree_menu) > .sub-menu .sub-level li a span:before{
    content: "";
    display: block;
    position: absolute;
    width: 4px;
    height: 4px;
    border-radius: 2px;
    background-color: #363636;
    left: 45px;
    top: 50%;
}

