<?php
// all allowed document types
$config['mime_type'] = [
    1 => [
        'header' => 'text/html',
        'name'   => 'html',
    ],
    2 => [
        'header' => 'text/plain',
        'name'   => 'text'
    ],
    3 => [
        'header' => 'application/json',
        'name'   => 'json'
    ],
];
