<table class="table">
    <thead>
        <tr>
            <th style="width: 15%">{ln_lang}</th>
            <th>
                {ln_content}
            </th>
            <th style="width: 10%">
                <label class="btn checkbox" style="float: right">
                    <input type="checkbox" name="editor" {editor} style="display: none">{ln_editor}
                </label>
            </th>
        </tr>
    </thead>
    <tbody>
        {item}
        <tr>
            <td>
                <p>{name}</p>
            </td>
            <td colspan="2">
                <textarea id="texteditor_{id_resource_type_resource}_{id_lan}" name="content[{id_lan}]" rows="15" style="width: 95%">{content}</textarea>
            </td>
        </tr>
        {/item}
        <?php if ($this->rt_user->isAllowed('resmng', 'private')) { ?>
            <tr>
                <td>
                    <i class="icon-eye-close"></i> {ln_alias}
                </td>
                <td colspan="2">
                    <input class="input-large" type="text" placeholder="{ln_not_necessarily}" name="alias" value="{alias}">
                </td>
            </tr>
        <?php } ?>
    </tbody>
</table>